@@ -1,14 +1,18 @@
-#' Defined multilayer motifs
+#' Interconnection motif forms
 #'
-#' Acquiring each or all of 48 motifs of definition of multilayer network.
+#' The dictionary of interconnection motif forms without intra-guild interactions.
 #'
-#' @param type Character. 49 values representing each and all types of multilayer motifs.
+#' @encoding UTF-8
+#'
+#' @param ID Character. Default to "all". See details for the IDs representing different motifs.
+#' @details
+#' An interconnection motif is defined to comprise three sets of connected nodes: the connector nodes (belonging to b-nodes), the nodes in one subnetwork (belonging to a-nodes in the P subnetwork), and the nodes in the other subnetwork (belonging to c-nodes in the Q subnetwork). Each motif has maximumly 6 nodes, resulting in a total of 48 distinct motif forms.
 #'
 #' @return
 #'
-#' If \code{type} is one of 48 motifs of definition, function returns a corresponding motif of "igraph".
+#' If \code{ID} is one ID, it returns a corresponding motif "igraph" object.
 #'
-#' If \code{type} is "all", function returns a list containing 48 corresponding motifs of "igraph".
+#' If \code{ID} is "all", it returns a list containing all 48 motifs of "igraph" objects.
 #'
 #' @export
 #'
@@ -18,7 +22,7 @@
 #' @importFrom igraph layout_with_sugiyama
 #' @examples
 #'
-#' type<-c("M111","M112","M113","M114","M211","M212","M213","M311",
+#' ID<-c("M111","M112","M113","M114","M211","M212","M213","M311",
 #' "M312","M411","M121","M122-1","M122-2","M122-3","M123-1",
 #' "M123-2","M123-3","M123-4","M123-5","M221-1","M221-2",
 #' "M221-3","M222-1","M222-2","M222-3","M222-4","M222-5",
@@ -30,24 +34,24 @@
 #' m<-Multi_motif("M222-4")
 #' plot(m,main="M222-4")
 #'
-#' mr <- par(mfrow=c(6,8),mar=c(1,1,3,1))
-#' for(i in 1:48){
+#' mr <- par(mfrow=c(4,6),mar=c(1,1,3,1))
+#' for(i in 1:24){
 #'     plot(Multi_motif("all")[[i]],
 #'     vertex.size=30, vertex.label=NA,
-#'     vertex.color="blue",main=type[i])
+#'     vertex.color="blue",main=ID[i])
 #' }
 #' par(mr)
 #'
 
- Multi_motif<-function(type=c("M111","M112","M113","M114","M211","M212","M213","M311","M312","M411","M121","M122-1",
+ Multi_motif<-function(ID=c("M111","M112","M113","M114","M211","M212","M213","M311","M312","M411","M121","M122-1",
                               "M122-2","M122-3","M123-1","M123-2","M123-3","M123-4","M123-5","M221-1","M221-2",
                               "M221-3","M222-1","M222-2","M222-3","M222-4","M222-5","M222-6","M222-7","M222-8",
                               "M222-9","M321-1","M321-2","M321-3","M321-4","M321-5","M131","M132-1","M132-2",
                               "M132-3","M132-4","M132-5","M231-1","M231-2","M231-3","M231-4","M231-5","M141",
                               "all")){
-    if(is.null(type))
-        type<-"all"
-    if(type=="M111"){
+    if(is.null(ID))
+        ID<-"all"
+    if(ID=="M111"){
         M111<-matrix(c("1","2","2","3"),2,2)
         M111<-graph_from_edgelist(M111)
         M111<-as.undirected(M111)
@@ -55,7 +59,7 @@
         M111$layout<-c(M111,layers=V(M111)$level)$layout
        return(M111)
     }
-    if(type=="M112"){
+    if(ID=="M112"){
        M112<-matrix(c("1","2","2","2","3","4"),3,2)
        M112<-graph_from_edgelist(M112)
        M112<-as.undirected(M112)
@@ -63,7 +67,7 @@
        M112$layout<-layout_with_sugiyama(M112,layers=V(M112)$level)$layout
        return(M112)
     }
-    if(type=="M113"){
+    if(ID=="M113"){
        M113<-matrix(c("1","2","2","2","2","3","4","5"),4,2)
        M113<-graph_from_edgelist(M113)
        M113<-as.undirected(M113)
@@ -71,7 +75,7 @@
        M113$layout<-layout_with_sugiyama(M113,layers=V(M113)$level)$layout
        return(M113)
     }
-    if(type=="M114"){
+    if(ID=="M114"){
         M114<-matrix(c("1","2","2","2","2","2","3","4","5","6"),5,2)
         M114<-graph_from_edgelist(M114)
         M114<-as.undirected(M114)
@@ -79,7 +83,7 @@
         M114$layout<-layout_with_sugiyama(M114,layers=V(M114)$level)$layout
         return(M114)
     }
-    if(type=="M211"){
+    if(ID=="M211"){
        M211<-matrix(c("1","2","3","3","3","4"),3,2)
        M211<-graph_from_edgelist(M211)
        NET<-as.undirected(M211)
@@ -90,7 +94,7 @@
        M211$layout<-layout_with_sugiyama(M211,layers=V(M211)$level)$layout
        return(M211)
     }
-    if(type=="M212"){
+    if(ID=="M212"){
        M212<-matrix(c("1","2","3","3","3","3","4","5"),4,2)
        M212<-graph_from_edgelist(M212)
        NET<-as.undirected(M212)
@@ -101,7 +105,7 @@
        M212$layout<-layout_with_sugiyama(M212,layers=V(M212)$level)$layout
        return(M212)
     }
-    if(type=="M213"){
+    if(ID=="M213"){
        M213<-matrix(c("1","2","3","3","3","3","3","4","5","6"),5,2)
        M213<-graph_from_edgelist(M213)
        NET<-as.undirected(M213)
@@ -112,7 +116,7 @@
        M213$layout<-layout_with_sugiyama(M213,layers=V(M213)$level)$layout
        return(M213)
     }
-    if(type=="M311"){
+    if(ID=="M311"){
        M311<-matrix(c("1","2","3","4","4","4","4","5"),4,2)
        M311<-graph_from_edgelist(M311)
        NET<-as.undirected(M311)
@@ -123,7 +127,7 @@
        M311$layout<-layout_with_sugiyama(M311,layers=V(M311)$level)$layout
        return(M311)
     }
-    if(type=="M312"){
+    if(ID=="M312"){
        M312<-matrix(c("1","2","3","4","4","4","4","4","5","6"),5,2)
        M312<-graph_from_edgelist(M312)
        NET<-as.undirected(M312)
@@ -134,7 +138,7 @@
        M312$layout<-layout_with_sugiyama(M312,layers=V(M312)$level)$layout
        return(M312)
     }
-    if(type=="M411"){
+    if(ID=="M411"){
         M411<-matrix(c("1","2","3","4","5","5","5","5","5","6"),5,2)
         M411<-graph_from_edgelist(M411)
         M411<-as.undirected(M411)
@@ -142,7 +146,7 @@
         M411$layout<-layout_with_sugiyama(M411,layers=V(M411)$level)$layout
         return(M411)
     }
-    if(type=="M121"){
+    if(ID=="M121"){
        M1211<-matrix(c("1","1","2","3","2","3","4","4"),4,2)
        M1211<-graph_from_edgelist(M1211)
        NET<-as.undirected(M1211)
@@ -153,7 +157,7 @@
        M1211$layout<-layout_with_sugiyama(M1211,layers=V(M1211)$level)$layout
        return(M1211)
     }
-    if(type=="M122-1"){
+    if(ID=="M122-1"){
        M1221<-matrix(c("1","2","1","3","2","4","3","5"),4,2)
        M1221<-graph_from_edgelist(M1221)
        NET<-as.undirected(M1221)
@@ -164,7 +168,7 @@
        M1221$layout<-layout_with_sugiyama(M1221,layers=V(M1221)$level)$layout
        return(M1221)
     }
-    if(type=="M122-2"){
+    if(ID=="M122-2"){
        M1222<-matrix(c("1","1","2","3","3","2","3","4","4","5"),5,2)
        M1222<-graph_from_edgelist(M1222)
        NET<-as.undirected(M1222)
@@ -175,7 +179,7 @@
        M1222$layout<-layout_with_sugiyama(M1222,layers=V(M1222)$level)$layout
        return(M1222)
     }
-    if(type=="M122-3"){
+    if(ID=="M122-3"){
        M1223<-matrix(c("1","1","2","2","3","3","2","3","4","5","4","5"),6,2)
        M1223<-graph_from_edgelist(M1223)
        NET<-as.undirected(M1223)
@@ -186,7 +190,7 @@
        M1223$layout<-layout_with_sugiyama(M1223,layers=V(M1223)$level)$layout
        return(M1223)
     }
-    if(type=="M123-1"){
+    if(ID=="M123-1"){
        M1231<-matrix(c("1","1","2","2","3","2","3","4","5","6"),5,2)
        M1231<-graph_from_edgelist(M1231)
        NET<-as.undirected(M1231)
@@ -197,7 +201,7 @@
        M1231$layout<-layout_with_sugiyama(M1231,layers=V(M1231)$level)$layout
        return(M1231)
     }
-    if(type=="M123-2"){
+    if(ID=="M123-2"){
        M1232<-matrix(c("1","1","2","3","3","3","2","3","4","4","5","6"),6,2)
        M1232<-graph_from_edgelist(M1232)
        NET<-as.undirected(M1232)
@@ -208,7 +212,7 @@
        M1232$layout<-layout_with_sugiyama(M1232,layers=V(M1232)$level)$layout
        return(M1232)
     }
-    if(type=="M123-3"){
+    if(ID=="M123-3"){
        M1233<-matrix(c("1","1","2","2","3","3","2","3","4","5","5","6"),6,2)
        M1233<-graph_from_edgelist(M1233)
        NET<-as.undirected(M1233)
@@ -219,7 +223,7 @@
        M1233$layout<-layout_with_sugiyama(M1233,layers=V(M1233)$level)$layout
        return(M1233)
     }
-    if(type=="M123-4"){
+    if(ID=="M123-4"){
        M1234<-matrix(c("1","1","2","2","2","3","3","2","3","4","5","6","5","6"),7,2)
        M1234<-graph_from_edgelist(M1234)
        NET<-as.undirected(M1234)
@@ -230,7 +234,7 @@
        M1234$layout<-layout_with_sugiyama(M1234,layers=V(M1234)$level)$layout
        return(M1234)
     }
-    if(type=="M123-5"){
+    if(ID=="M123-5"){
        M1235<-matrix(c("1","1","2","2","2","3","3","3","2","3","4","5","6","4","5","6"),8,2)
        M1235<-graph_from_edgelist(M1235)
        NET<-as.undirected(M1235)
@@ -241,7 +245,7 @@
        M1235$layout<-layout_with_sugiyama(M1235,layers=V(M1235)$level)$layout
        return(M1235)
     }
-    if(type=="M221-1"){
+    if(ID=="M221-1"){
        M2211<-matrix(c("1","2","3","4","3","4","5","5"),4,2)
        M2211<-graph_from_edgelist(M2211)
        NET<-as.undirected(M2211)
@@ -252,7 +256,7 @@
        M2211$layout<-layout_with_sugiyama(M2211,layers=V(M2211)$level)$layout
        return(M2211)
     }
-    if(type=="M221-2"){
+    if(ID=="M221-2"){
        M2212<-matrix(c("1","2","2","3","4","3","3","4","5","5"),5,2)
        M2212<-graph_from_edgelist(M2212)
        NET<-as.undirected(M2212)
@@ -263,7 +267,7 @@
        M2212$layout<-layout_with_sugiyama(M2212,layers=V(M2212)$level)$layout
        return(M2212)
     }
-    if(type=="M221-3"){
+    if(ID=="M221-3"){
        M2213<-matrix(c("1","1","2","2","3","4","3","4","3","4","5","5"),6,2)
        M2213<-graph_from_edgelist(M2213)
        NET<-as.undirected(M2213)
@@ -274,7 +278,7 @@
        M2213$layout<-layout_with_sugiyama(M2213,layers=V(M2213)$level)$layout
        return(M2213)
     }
-    if(type=="M222-1"){
+    if(ID=="M222-1"){
        M2221<-matrix(c("1","2","2","3","4","3","3","4","5","6"),5,2)
        M2221<-graph_from_edgelist(M2221)
        NET<-as.undirected(M2221)
@@ -285,7 +289,7 @@
        M2221$layout<-layout_with_sugiyama(M2221,layers=V(M2221)$level)$layout
        return(M2221)
     }
-    if(type=="M222-2"){
+    if(ID=="M222-2"){
        M2222<-matrix(c("1","1","2","2","3","4","3","4","3","4","5","6"),6,2)
        M2222<-graph_from_edgelist(M2222)
        NET<-as.undirected(M2222)
@@ -297,7 +301,7 @@
 
        return(M2222)
     }
-    if(type=="M222-3"){
+    if(ID=="M222-3"){
        M2223<-matrix(c("1","2","3","3","4","3","4","5","6","6"),5,2)
        M2223<-graph_from_edgelist(M2223)
        NET<-as.undirected(M2223)
@@ -308,7 +312,7 @@
        M2223$layout<-layout_with_sugiyama(M2223,layers=V(M2223)$level)$layout
        return(M2223)
     }
-    if(type=="M222-4"){
+    if(ID=="M222-4"){
        M2224<-matrix(c("1","2","2","3","3","4","3","3","4","5","6","6"),6,2)
        M2224<-graph_from_edgelist(M2224)
        NET<-as.undirected(M2224)
@@ -319,7 +323,7 @@
        M2224$layout<-layout_with_sugiyama(M2224,layers=V(M2224)$level)$layout
        return(M2224)
     }
-    if(type=="M222-5"){
+    if(ID=="M222-5"){
        M2225<-matrix(c("1","1","2","2","3","4","4","3","4","3","4","5","5","6"),7,2)
        M2225<-graph_from_edgelist(M2225)
        NET<-as.undirected(M2225)
@@ -330,7 +334,7 @@
        M2225$layout<-layout_with_sugiyama(M2225,layers=V(M2225)$level)$layout
        return(M2225)
     }
-    if(type=="M222-6"){
+    if(ID=="M222-6"){
        M2226<-matrix(c("1","2","3","3","4","4","3","4","5","6","5","6"),6,2)
        M2226<-graph_from_edgelist(M2226)
        NET<-as.undirected(M2226)
@@ -341,7 +345,7 @@
        M2226$layout<-layout_with_sugiyama(M2226,layers=V(M2226)$level)$layout
        return(M2226)
     }
-    if(type=="M222-7"){
+    if(ID=="M222-7"){
        M2227<-matrix(c("1","2","2","3","3","4","4","3","3","4","5","6","5","6"),7,2)
        M2227<-graph_from_edgelist(M2227)
        NET<-as.undirected(M2227)
@@ -352,7 +356,7 @@
        M2227$layout<-layout_with_sugiyama(M2227,layers=V(M2227)$level)$layout
        return(M2227)
     }
-    if(type=="M222-8"){
+    if(ID=="M222-8"){
        M2228<-matrix(c("1","1","2","2","3","3","4","4","3","4","3","4","5","6","5","6"),8,2)
        M2228<-graph_from_edgelist(M2228)
        NET<-as.undirected(M2228)
@@ -363,7 +367,7 @@
        M2228$layout<-layout_with_sugiyama(M2228,layers=V(M2228)$level)$layout
        return(M2228)
     }
-    if(type=="M222-9"){
+    if(ID=="M222-9"){
         M2229<-matrix(c("1","2","2","3","4","4","3","3","4","5","5","6"),6,2)
         M2229<-graph_from_edgelist(M2229)
         NET<-as.undirected(M2229)
@@ -374,7 +378,7 @@
         M2229$layout<-layout_with_sugiyama(M2229,layers=V(M2229)$level)$layout
         return(M2229)
     }
-    if(type=="M321-1"){
+    if(ID=="M321-1"){
        M3211<-matrix(c("1","2","3","4","5","4","4","5","6","6"),5,2)
        M3211<-graph_from_edgelist(M3211)
        NET<-as.undirected(M3211)
@@ -385,7 +389,7 @@
        M3211$layout<-layout_with_sugiyama(M3211,layers=V(M3211)$level)$layout
        return(M3211)
     }
-    if(type=="M321-2"){
+    if(ID=="M321-2"){
        M3212<-matrix(c("1","1","2","3","4","5","4","5","5","5","6","6"),6,2)
        M3212<-graph_from_edgelist(M3212)
        NET<-as.undirected(M3212)
@@ -396,7 +400,7 @@
        M3212$layout<-layout_with_sugiyama(M3212,layers=V(M3212)$level)$layout
        return(M3212)
     }
-    if(type=="M321-3"){
+    if(ID=="M321-3"){
        M3213<-matrix(c("1","2","2","3","4","5","4","4","5","5","6","6"),6,2)
        M3213<-graph_from_edgelist(M3213)
        NET<-as.undirected(M3213)
@@ -407,7 +411,7 @@
        M3213$layout<-layout_with_sugiyama(M3213,layers=V(M3213)$level)$layout
        return(M3213)
     }
-    if(type=="M321-4"){
+    if(ID=="M321-4"){
        M3214<-matrix(c("1","1","2","2","3","4","5","4","5","4","5","5","6","6"),7,2)
        M3214<-graph_from_edgelist(M3214)
        NET<-as.undirected(M3214)
@@ -418,7 +422,7 @@
        M3214$layout<-layout_with_sugiyama(M3214,layers=V(M3214)$level)$layout
        return(M3214)
     }
-    if(type=="M321-5"){
+    if(ID=="M321-5"){
        M3215<-matrix(c("1","1","2","2","3","3","4","5","4","5","4","5","4","5","6","6"),8,2)
        M3215<-graph_from_edgelist(M3215)
        NET<-as.undirected(M3215)
@@ -429,7 +433,7 @@
        M3215$layout<-layout_with_sugiyama(M3215,layers=V(M3215)$level)$layout
        return(M3215)
     }
-    if(type=="M131"){
+    if(ID=="M131"){
        M131<-matrix(c("1","1","1","2","3","4","2","3","4","5","5","5"),6,2)
        M131<-graph_from_edgelist(M131)
        NET<-as.undirected(M131)
@@ -440,7 +444,7 @@
        M131$layout<-layout_with_sugiyama(M131,layers=V(M131)$level)$layout
        return(M131)
     }
-    if(type=="M132-1"){
+    if(ID=="M132-1"){
        M1321<-matrix(c("1","1","1","2","3","4","2","3","4","5","5","6"),6,2)
        M1321<-graph_from_edgelist(M1321)
        NET<-as.undirected(M1321)
@@ -451,7 +455,7 @@
        M1321$layout<-layout_with_sugiyama(M1321,layers=V(M1321)$level)$layout
        return(M1321)
     }
-    if(type=="M132-2"){
+    if(ID=="M132-2"){
        M1322<-matrix(c("1","1","1","2","2","3","4","2","3","4","5","6","6","6"),7,2)
        M1322<-graph_from_edgelist(M1322)
        NET<-as.undirected(M1322)
@@ -462,7 +466,7 @@
        M1322$layout<-layout_with_sugiyama(M1322,layers=V(M1322)$level)$layout
        return(M1322)
     }
-    if(type=="M132-3"){
+    if(ID=="M132-3"){
        M1323<-matrix(c("1","1","1","2","3","3","4","2","3","4","5","5","6","6"),7,2)
        M1323<-graph_from_edgelist(M1323)
        NET<-as.undirected(M1323)
@@ -473,7 +477,7 @@
        M1323$layout<-layout_with_sugiyama(M1323,layers=V(M1323)$level)$layout
        return(M1323)
     }
-    if(type=="M132-4"){
+    if(ID=="M132-4"){
        M1324<-matrix(c("1","1","1","2","2","3","3","4","2","3","4","5","6","5","6","6"),8,2)
        M1324<-graph_from_edgelist(M1324)
        NET<-as.undirected(M1324)
@@ -484,7 +488,7 @@
        M1324$layout<-layout_with_sugiyama(M1324,layers=V(M1324)$level)$layout
        return(M1324)
     }
-    if(type=="M132-5"){
+    if(ID=="M132-5"){
        M1325<-matrix(c("1","1","1","2","2","3","3","4","4","2","3","4","5","6","5","6","5","6"),9,2)
        M1325<-graph_from_edgelist(M1325)
        NET<-as.undirected(M1325)
@@ -495,7 +499,7 @@
        M1325$layout<-layout_with_sugiyama(M1325,layers=V(M1325)$level)$layout
        return(M1325)
     }
-    if(type=="M231-1"){
+    if(ID=="M231-1"){
        M2311<-matrix(c("1","1","2","3","4","5","3","4","5","6","6","6"),6,2)
        M2311<-graph_from_edgelist(M2311)
        NET<-as.undirected(M2311)
@@ -506,7 +510,7 @@
        M2311$layout<-layout_with_sugiyama(M2311,layers=V(M2311)$level)$layout
        return(M2311)
     }
-    if(type=="M231-2"){
+    if(ID=="M231-2"){
        M2312<-matrix(c("1","2","2","2","3","4","5","3","3","4","5","6","6","6"),7,2)
        M2312<-graph_from_edgelist(M2312)
        NET<-as.undirected(M2312)
@@ -517,7 +521,7 @@
        M2312$layout<-layout_with_sugiyama(M2312,layers=V(M2312)$level)$layout
        return(M2312)
     }
-    if(type=="M231-3"){
+    if(ID=="M231-3"){
        M2313<-matrix(c("1","1","2","2","3","4","5","3","4","4","5","6","6","6"),7,2)
        M2313<-graph_from_edgelist(M2313)
        NET<-as.undirected(M2313)
@@ -528,7 +532,7 @@
        M2313$layout<-layout_with_sugiyama(M2313,layers=V(M2313)$level)$layout
        return(M2313)
     }
-    if(type=="M231-4"){
+    if(ID=="M231-4"){
        M2314<-matrix(c("1","1","1","2","2","3","4","5","3","4","5","4","5","6","6","6"),8,2)
        M2314<-graph_from_edgelist(M2314)
        NET<-as.undirected(M2314)
@@ -539,7 +543,7 @@
        M2314$layout<-layout_with_sugiyama(M2314,layers=V(M2314)$level)$layout
        return(M2314)
     }
-    if(type=="M231-5"){
+    if(ID=="M231-5"){
        M2315<-matrix(c("1","1","1","2","2","2","3","4","5","3","4","5","3","4","5","6","6","6"),9,2)
        M2315<-graph_from_edgelist(M2315)
        NET<-as.undirected(M2315)
@@ -550,7 +554,7 @@
        M2315$layout<-layout_with_sugiyama(M2315,layers=V(M2315)$level)$layout
        return(M2315)
     }
-    if(type=="M141"){
+    if(ID=="M141"){
         M141<-matrix(c("1","1","1","1","2","3","4","5","2","3","4","5","6","6","6","6"),8,2)
         M141<-graph_from_edgelist(M141)
         NET<-as.undirected(M141)
@@ -562,7 +566,7 @@
         return(M141)
     }
 
-    if(type=="all"){
+    if(ID=="all"){
        M111<-matrix(c("1","2","2","3"),2,2)
        M111<-graph_from_edgelist(M111)
        M111<-as.undirected(M111)
